from bitmovin_api_sdk.player.custom_builds.web.web_api import WebApi
from bitmovin_api_sdk.player.custom_builds.web.domains.domains_api import DomainsApi
from bitmovin_api_sdk.player.custom_builds.web.status.status_api import StatusApi
from bitmovin_api_sdk.player.custom_builds.web.download.download_api import DownloadApi
